@@ -1,8 +1,7 @@
 """Module to deal with ipsw files."""
+import sys
 import os
 import shutil
-import sys
-
 import requests
 from remotezip import RemoteZip
 
@@ -73,9 +72,9 @@ def get_json_data(model: str, fw_type: str = "ota") -> dict:
 
 def get_firmware_url(json_data: dict, buildid: str) -> str:
     """Return URL of IPSW file."""
-    for firmware in json_data["firmwares"]:
-        if firmware["buildid"] == buildid:
-            return firmware["url"]
+    for i in range(0, len(json_data["firmwares"])):
+        if json_data["firmwares"][i]["buildid"] == buildid:
+            return json_data["firmwares"][i]["url"]
     return None
 
 
@@ -92,29 +91,29 @@ def get_build_id(json_data: dict, ios_vers: str, fw_type: str = "ota") -> str:
         print("[e] no iOS version specified")
         return sys.exit(1)
 
-    for firmware in json_data["firmwares"]:
-        curent_vers = firmware["version"]
+    for i in range(0, len(json_data["firmwares"])):
+        curent_vers = json_data["firmwares"][i]["version"]
         if fw_type == "ota":
-            release = firmware["releasetype"]
+            release = json_data["firmwares"][i]["releasetype"]
 
         if ios_vers in curent_vers and release == "":
-            return firmware["buildid"]
+            return json_data["firmwares"][i]["buildid"]
     return None
 
 
-def get_ios_vers(json_data: dict, buildid: str) -> str:
-    """"Return iOS version of build ID."""
+def get_ios_vers(json_data: dict, buildid) -> str:
+    """ "Return iOS version of build ID."""
     if json_data is None:
         return None
-    for firmware in json_data["firmwares"]:
-        if firmware["buildid"] == buildid:
-            return firmware["version"]
+    for i in range(0, len(json_data["firmwares"])):
+        if json_data["firmwares"][i]["buildid"] == buildid:
+            return json_data["firmwares"][i]["version"]
     return None
 
 
 def get_build_list(json_data: dict) -> list:
     """Return a list of build IDs for a device"""
     builds = []
-    for firmware in json_data["firmwares"]:
-        builds.append(firmware["buildid"])
+    for i in range(len(json_data["firmwares"])):
+        builds.append(json_data["firmwares"][i]["buildid"])
     return builds
